@@ -400,11 +400,11 @@ class Backend:
 
     # Api for getting a set of resources that match the given tag from the backend
     def get_resources_by_tag(
-            self,
-            resource_state_uuid: str,
-            component_name: str,
-            resource_type: str,
-            resource_tag: str,
+        self,
+        resource_state_uuid: str,
+        component_name: str,
+        resource_type: str,
+        resource_tag: str,
     ) -> List[ResourceModel]:
         """
         Get the state of a resource from a component based on the name of the resource
@@ -525,6 +525,23 @@ class Backend:
         """
         raise NotImplementedError
 
+    def remove_resource(
+        self,
+        resource_state_uuid: str,
+        component_name: str,
+        resource_type: str,
+        resource_name: str,
+    ):
+        """Remove the resource from the backend.
+
+        Args:
+            resource_state_uuid (str): _description_
+            component_name (str): _description_
+            resource_type (str): _description_
+            resource_name (str): _description_
+        """
+        raise NotImplementedError
+
 
 def load_backend(config: Backend_Configuration) -> Backend:
     """Dynamically load a backend
